aboutsummaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2010-03-18 16:01:11 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2010-03-18 16:01:11 +0000
commitcf1b70f486a2696d523d585e91d0e4e5c7b8021c (patch)
tree8bb98eff1c20929200b6c89da6b87ff47bd99af8 /test
parent7ae3e3227ee895c3ed5ac3358411b07276c7838e (diff)
downloadChibiOS-cf1b70f486a2696d523d585e91d0e4e5c7b8021c.tar.gz
ChibiOS-cf1b70f486a2696d523d585e91d0e4e5c7b8021c.tar.bz2
ChibiOS-cf1b70f486a2696d523d585e91d0e4e5c7b8021c.zip
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@1749 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'test')
-rw-r--r--test/testbmk.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/testbmk.c b/test/testbmk.c
index e07b7018b..46c30081e 100644
--- a/test/testbmk.c
+++ b/test/testbmk.c
@@ -356,7 +356,7 @@ const struct testcase testbmk6 = {
};
/**
* @page test_benchmarks_007 Mass reschedulation performance
*
* <h2>Description</h2>
* Five threads are created and atomically reschedulated by resetting the
@@ -376,7 +376,7 @@ static msg_t thread3(void *p) {
static char *bmk7_gettest(void) {
- return "Benchmark, mass reschedulation, 5 threads";
+ return "Benchmark, mass reschedule, 5 threads";
}
static void bmk7_setup(void) {
@@ -409,7 +409,7 @@ static void bmk7_execute(void) {
test_print("--- Score : ");
test_printn(n);
- test_print(" reschedulations/S, ");
+ test_print(" reschedules/S, ");
test_printn(n * 6);
test_println(" ctxswc/S");
}
@@ -422,7 +422,7 @@ const struct testcase testbmk7 = {
};
/**
- * @page test_benchmarks_008 I/O Round-Robin voluntary reschedulation.
+ * @page test_benchmarks_008 I/O Round-Robin voluntary reschedule.
*
* <h2>Description</h2>
* Five threads are created at equal priority, each thread just increases a
@@ -469,7 +469,7 @@ static void bmk8_execute(void) {
test_print("--- Score : ");
test_printn(n);
- test_print(" reschedulations/S, ");
+ test_print(" reschedules/S, ");
test_printn(n);
test_println(" ctxswc/S");
}
@@ -356,7 +356,7 @@ const struct testcase testbmk6 = {
};
/**
- * @page test_benchmarks_007 Mass reschedulation performance
+ * @page test_benchmarks_007 Mass reschedule performance
*
* <h2>Description</h2>